==> lcmaps-plugins-c-pep_1.2.3.orig.tar.gz: lcmaps-plugins-c-pep-1.2.3/src/c-pep/pep-c-obligation-handlers.h <==
/**
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 *
 *  Authors:
 *  2009-
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     Mischa Sall\'e <msalle@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *     <grid-mw-security@nikhef.nl>
 *
 */


#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include <string.h>

#include <sys/types.h>
#include <pwd.h>
#include <grp.h>

#include <lcmaps/lcmaps_log.h>

/* include lcmaps_c_pep_config.h for PEP_API */
#include "lcmaps_c_pep_config.h"

#if PEP_API == 1
#include <pep/pep.h>
#else
#include <argus/pep.h>
#endif

#include "pep-c-interact.h"




#ifndef PEP_C_OBLIGATION_HANDLERS_H
    #define PEP_C_OBLIGATION_HANDLERS_H


#ifndef MAX_APPEARANCE_OF_OBLIGATION_UIDGID
    #define MAX_APPEARANCE_OF_OBLIGATION_UIDGID 1 
#endif
#ifndef MAX_APPEARANCE_OF_ATTRIB_UID
    #define MAX_APPEARANCE_OF_ATTRIB_UID        1 
#endif
#ifndef MAX_APPEARANCE_OF_ATTRIB_PRI_GID
    #define MAX_APPEARANCE_OF_ATTRIB_PRI_GID    1
#endif
#ifndef MAX_APPEARANCE_OF_ATTRIB_SEC_GID
    #define MAX_APPEARANCE_OF_ATTRIB_SEC_GID    32
#endif



int registerObligationHandlers (pep_obligationhandler_t **, int *);

int oh_init_uidgid (void);
int oh_process_uidgid (xacml_request_t **, xacml_response_t **);
int oh_destroy_uidgid (void);

int oh_init_secondarygids (void);
int oh_process_secondarygids (xacml_request_t **, xacml_response_t **);
int oh_destroy_secondarygids (void);

int oh_init_username (void);
int oh_process_username (xacml_request_t **, xacml_response_t **);
int oh_destroy_username (void);

int oh_init_local_environment_map_posix (void);
int oh_process_local_environment_map_posix (xacml_request_t ** this_request, xacml_response_t ** this_response);
int oh_destroy_local_environment_map_posix (void);

#endif /* PEP_C_OBLIGATION_HANDLERS_H */

==> lcmaps-plugins-c-pep_1.2.6.orig.tar.gz: lcmaps-plugins-c-pep-1.2.6/src/c-pep/pep-c-obligation-handlers.h <==
/**
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 *
 *  Authors:
 *  2009-
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     Mischa Sall\'e <msalle@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *     <grid-mw-security@nikhef.nl>
 *
 */


#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include <string.h>

#include <sys/types.h>
#include <pwd.h>
#include <grp.h>

#include <lcmaps/lcmaps_log.h>

/* include lcmaps_c_pep_config.h for PEP_API */
#include "lcmaps_c_pep_config.h"

#if PEP_API == 1
#include <pep/pep.h>
#else
#include <argus/pep.h>
#endif

#include "pep-c-interact.h"




#ifndef PEP_C_OBLIGATION_HANDLERS_H
    #define PEP_C_OBLIGATION_HANDLERS_H


#ifndef MAX_APPEARANCE_OF_OBLIGATION_UIDGID
    #define MAX_APPEARANCE_OF_OBLIGATION_UIDGID 1 
#endif
#ifndef MAX_APPEARANCE_OF_ATTRIB_UID
    #define MAX_APPEARANCE_OF_ATTRIB_UID        1 
#endif
#ifndef MAX_APPEARANCE_OF_ATTRIB_PRI_GID
    #define MAX_APPEARANCE_OF_ATTRIB_PRI_GID    1
#endif
#ifndef MAX_APPEARANCE_OF_ATTRIB_SEC_GID
    #define MAX_APPEARANCE_OF_ATTRIB_SEC_GID    32
#endif



int registerObligationHandlers (pep_obligationhandler_t **, size_t *);

int oh_init_uidgid (void);
int oh_process_uidgid (xacml_request_t **, xacml_response_t **);
int oh_destroy_uidgid (void);

int oh_init_secondarygids (void);
int oh_process_secondarygids (xacml_request_t **, xacml_response_t **);
int oh_destroy_secondarygids (void);

int oh_init_username (void);
int oh_process_username (xacml_request_t **, xacml_response_t **);
int oh_destroy_username (void);

int oh_init_local_environment_map_posix (void);
int oh_process_local_environment_map_posix (xacml_request_t ** this_request, xacml_response_t ** this_response);
int oh_destroy_local_environment_map_posix (void);

#endif /* PEP_C_OBLIGATION_HANDLERS_H */
